FixedAssetLine

Enum FixedAssetLine 

pub enum FixedAssetLine {
Show 256 variants OneToFourUnit, FiveOrMoreUnit, Accommodation, AccommodationFoodServices, AdministrativeSupportServices, AdministrativeWasteManagementServices, AerospaceProductsPartsManufacturing, AgriculturalMachinery, AgricultureForestryFishingHunting, Air, AirTransportation, Aircraft, AllOtherNonmanufacturing, AmbulatoryHealthCareServices, AmusementRecreation, AmusementsGamblingRecreationIndustries, ApparelLeatherAlliedProducts, ArtsEntertainmentRecreation, Autos, BeverageTobaccoProductManufacturing, Books, BroadcastingTelecommunications, BrokersCommissionsOtherOwnershipTransferCosts, Buildings, Business, ChemicalManufacturingExcludingPharmaceuticalMedicine, ChemicalProducts, Commercial, CommercialHealthCare, Communication, CommunicationEquipment, ComputerElectronicProducts, ComputerSystemsDesignRelatedServices, ComputersPeripheralEquipment, ConservationDevelopment, Construction, ConstructionMachinery, ConsumerDurableGoods, Corporate, CreditIntermediationRelatedActivities, Custom, DepositoryreditIntermediation, DurableGoods, Educational, EducationalVocational, EducationalBooks, EducationalServices, Electric, ElectricPower, ElectricalEquipmentAppliancesComponents, ElectricalEquipmentNec, ElectricalTransmissionDistributionIndustrialApparatus, Electronics, EnginesTurbines, EntertainmentLiteraryArtisticOriginals, Equipment, FabricatedMetalProducts, Farm, Farms, Federal, FederalReserveBanks, FinanceInsurance, Financial, FixedAssets, FixedAssetsConsumerDurableGoods, FoodBeverageTobaccoProducts, FoodBeverageEstablishments, FoodBeverageStores, FoodManufacturing, FoodServicesDrinkingPlaces, ForestryFishingRelatedActivities, FundsTrustsOtherFinancialVehicles, FurnishingsDurableHouseholdEquipment, FurnitureFixtures, FurnitureFurnishings, FurnitureRelatedProducts, GeneralGovernmentFixedAssets, GeneralIndustrialIncludingMaterialsHandlingEquipment, GeneralMerchandiseStores, GlasswareTablewareHouseholdUtensils, Government, GovernmentEnterpriseFixedAssets, GovernmentFixedAssets, GovernmentNonresidentialFixedAssets, HealthSocialAssistance, HealthCare, HighwaysStreets, Hospitals, HospitalsSpecialCare, HouseholdAppliances, Households, HousingUnits, Improvements, Industrial, IndustrialEquipment, Information, InformationDataProcessingServices, InformationProcessingEquipment, InsuranceAgenciesBrokersRelatedServices, InsuranceCarriers, InsuranceCarriersRelatedActivities, IntellectualPropertyProducts, JewelryWatches, Land, LegalServices, LightTrucks, LightTrucksIncludingUtilityVehicles, Lodging, LongLivedTelevisionPrograms, LuggageSimilarPersonalItems, Machinery, ManagementOfCompaniesEnterprises, ManufacturedHomes, Manufacturing, MedicalBuildings, MedicalEquipmentInstruments, MedicalEquipmentSupplies, MetalworkingMachinery, MilitaryFacilities, Mining, MiningOilfieldMachinery, MiningExplorationShaftsWells, MiningExceptOilGas, MiscellaneousManufacturing, MiscellaneousProfessionalScientificTechnicalServices, Missiles, MotionPictureSoundRecordingIndustries, MotorVehiclePartsDealers, MotorVehiclePartsAccessories, MotorVehiclesParts, MotorVehiclesBodiesTrailersParts, MotorVehiclesBodiesTrailersPartsManufacturing, MultimerchandiseShopping, Music, MusicalInstruments, NationalDefense, NaturalGasDistribution, Noncorporate, Nondefense, NondepositoryCreditIntermediation, NondurableGoods, NonfarmNonmanufacturing, NonfarmNonmanufacturingNonresidentialFixedAssetsOnly, Nonfinancial, Nonmanufacturing, NonmedicalInstruments, NonmetallicMineralProducts, NonprofitInstitutions, NonprofitInstitutionsServingHouseholdsNpishs, Nonresidential, NonresidentialEquipment, NonresidentialIntellectualPropertyProducts, NonresidentialStructures, NursingResidentialCareFacilities, Office, OfficeAccountingEquipment, OilGasExtraction, Other, OtherCommercial, OtherComputerElectronicProductManufacturing, OtherDurableGoods, OtherEquipment, OtherIntermediation, OtherManufacturing, OtherNonprofitInstitutions, OtherNonresidentialEquipment, OtherPower, OtherResidential, OtherRetail, OtherServicesExceptGovernment, OtherStructures, OtherTransportationSupportActivities, OtherTransportationEquipment, OtherTrucksBusesTruckTrailers, OwnAccount, OwnerOccupied, PaperProducts, Partnerships, PerformingArtsSpectatorSportsMuseumsRelatedActivities, PermanentSite, PetroleumCoalProducts, PetroleumNaturalGas, PharmaceuticalMedicineManufacturing, PhotocopyRelatedEquipment, PipelineTransportation, PlasticsRubberProducts, Power, PowerCommunication, Prepackaged, PrimaryMetals, PrintingRelatedSupportActivities, Private, PrivateGovernmentFixedAssets, PrivateFixedAssets, PrivateNonresidentialFixedAssets, ProfessionalScientificTechnicalServices, PublicSafety, PublishingIndustriesIncludesSoftware, RailroadEquipment, RailroadTransportation, RealEstate, RealEstateRentalLeasing, RecreationalBooks, RecreationalGoodsVehicles, Religious, RentalLeasingServicesLessorsOfIntangibleAssets, ResearchDevelopment, Residential, ResidentialEquipment, ResidentialFixedAssets, ResidentialStructures, RetailTrade, ScientificResearchDevelopmentServices, SecuritiesCommodityContractsInvestments, SemiconductorOtherElectronicComponentManufacturing, ServiceIndustryMachinery, SewerSystems, Ships, ShipsBoats, SocialAssistance, Software, SoleProprietorships, SoleProprietorshipsPartnerships, SpecialCare, SpecialIndustryMachineryNec, SportingEquipmentSuppliesGunsAmmunition, SportsRecreationalVehicles, StateLocal, Structures, SupportActivitiesForMining, TaxExemptCooperatives, TelephoneFacsimileEquipment, TenantOccupied, TextileMillsTextileProductMills, TheatricalMovies, TherapeuticAppliancesEquipment, ToolsEquipmentForHouseGarden, TransitGroundPassengerTransportation, Transportation, TransportationWarehousing, TransportationEquipment, Transportion, TruckTransportation, TrucksBusesTruckTrailers, UniversitiesColleges, Utilities, Vehicles, VideoAudioPhotographicInformationProcessingEquipmentMedia, Warehouses, WarehousingStorage, WasteManagementRemediationServices, WaterSystems, WaterTransportation, WaterSewageOtherSystems, WholesaleTrade, WoodProducts,
}
Fixed asset line classifications

Variants



OneToFourUnit

1 to 4 unit



FiveOrMoreUnit

5-or more-unit



Accommodation

Accommodation



AccommodationFoodServices

Accommodation and food services



AdministrativeSupportServices

Administrative and support services



AdministrativeWasteManagementServices

Administrative and waste management services



AerospaceProductsPartsManufacturing

Aerospace products and parts manufacturing



AgriculturalMachinery

Agricultural machinery



AgricultureForestryFishingHunting

Agriculture, forestry, fishing, and hunting



Air

Air



AirTransportation

Air transportation



Aircraft

Aircraft



AllOtherNonmanufacturing

All other nonmanufacturing



AmbulatoryHealthCareServices

Ambulatory health care services



AmusementRecreation

Amusement and recreation



AmusementsGamblingRecreationIndustries

Amusements, gambling, and recreation industries



ApparelLeatherAlliedProducts

Apparel and leather and allied products



ArtsEntertainmentRecreation

Arts, entertainment, and recreation



Autos

Autos



BeverageTobaccoProductManufacturing

Beverage and tobacco product manufacturing



Books

Books



BroadcastingTelecommunications

Broadcasting and telecommunications



BrokersCommissionsOtherOwnershipTransferCosts

Brokers’ commissions and other ownership transfer costs



Buildings

Buildings



Business

Business



ChemicalManufacturingExcludingPharmaceuticalMedicine

Chemical manufacturing, excluding pharmaceutical and medicine



ChemicalProducts

Chemical products



Commercial

Commercial



CommercialHealthCare

Commercial and health care



Communication

Communication



CommunicationEquipment

Communication equipment



ComputerElectronicProducts

Computer and electronic products



ComputerSystemsDesignRelatedServices

Computer systems design and related services



ComputersPeripheralEquipment

Computers and peripheral equipment



ConservationDevelopment

Conservation and development



Construction

Construction



ConstructionMachinery

Construction machinery



ConsumerDurableGoods

Consumer durable goods



Corporate

Corporate



CreditIntermediationRelatedActivities

Credit intermediation and related activities



Custom

Custom



DepositoryreditIntermediation

Depository credit intermediation



DurableGoods

Durable goods



Educational

Educational



EducationalVocational

Educational and vocational



EducationalBooks

Educational books



EducationalServices

Educational services



Electric

Electric



ElectricPower

Electric power



ElectricalEquipmentAppliancesComponents

Electrical equipment, appliances, and components



ElectricalEquipmentNec

Electrical equipment, n.e.c.



ElectricalTransmissionDistributionIndustrialApparatus

Electrical transmission, distribution, and industrial apparatus



Electronics

Electronics



EnginesTurbines

Engines and turbines



EntertainmentLiteraryArtisticOriginals

Entertainment, literary, and artistic originals



Equipment

Equipment



FabricatedMetalProducts

Fabricated metal products



Farm

Farm



Farms

Farms



Federal

Federal



FederalReserveBanks

Federal Reserve banks



FinanceInsurance

Finance and insurance



Financial

Financial



FixedAssets

Fixed assets



FixedAssetsConsumerDurableGoods

Fixed assets and consumer durable goods



FoodBeverageTobaccoProducts

Food and beverage and tobacco products



FoodBeverageEstablishments

Food and beverage establishments



FoodBeverageStores

Food and beverage stores



FoodManufacturing

Food manufacturing



FoodServicesDrinkingPlaces

Food services and drinking places



ForestryFishingRelatedActivities

Forestry, fishing, and related activities



FundsTrustsOtherFinancialVehicles

Funds, trusts, and other financial vehicles



FurnishingsDurableHouseholdEquipment

Furnishings and durable household equipment



FurnitureFixtures

Furniture and fixtures



FurnitureFurnishings

Furniture and furnishings



FurnitureRelatedProducts

Furniture and related products



GeneralGovernmentFixedAssets

General government fixed assets



GeneralIndustrialIncludingMaterialsHandlingEquipment

General industrial, including materials handling, equipment



GeneralMerchandiseStores

General merchandise stores



GlasswareTablewareHouseholdUtensils

Glassware, tableware, and household utensils



Government

Government



GovernmentEnterpriseFixedAssets

Government enterprise fixed assets



GovernmentFixedAssets

Government fixed assets



GovernmentNonresidentialFixedAssets

Government nonresidential fixed assets



HealthSocialAssistance

Health and social assistance



HealthCare

Health care



HighwaysStreets

Highways and streets



Hospitals

Hospitals



HospitalsSpecialCare

Hospitals and special care



HouseholdAppliances

Household appliances



Households

Households



HousingUnits

Housing units



Improvements

Improvements



Industrial

Industrial



IndustrialEquipment

Industrial equipment



Information

Information



InformationDataProcessingServices

Information and data processing services



InformationProcessingEquipment

Information processing equipment



InsuranceAgenciesBrokersRelatedServices

Insurance agencies and brokers and related services



InsuranceCarriers

Insurance carriers



InsuranceCarriersRelatedActivities

Insurance carriers and related activities



IntellectualPropertyProducts

Intellectual property products



JewelryWatches

Jewelry and watches



Land

Land



LegalServices

Legal services



LightTrucks

Light trucks



LightTrucksIncludingUtilityVehicles

Light trucks (including utility vehicles)



Lodging

Lodging



LongLivedTelevisionPrograms

Long-lived television programs



LuggageSimilarPersonalItems

Luggage and similar personal items



Machinery

Machinery



ManagementOfCompaniesEnterprises

Management of companies and enterprises



ManufacturedHomes

Manufactured homes



Manufacturing

Manufacturing



MedicalBuildings

Medical buildings



MedicalEquipmentInstruments

Medical equipment and instruments



MedicalEquipmentSupplies

Medical equipment and supplies



MetalworkingMachinery

Metalworking machinery



MilitaryFacilities

Military facilities



Mining

Mining



MiningOilfieldMachinery

Mining and oilfield machinery



MiningExplorationShaftsWells

Mining exploration, shafts, and wells



MiningExceptOilGas

Mining, except oil and gas



MiscellaneousManufacturing

Miscellaneous manufacturing



MiscellaneousProfessionalScientificTechnicalServices

Miscellaneous professional, scientific, and technical services



Missiles

Missiles



MotionPictureSoundRecordingIndustries

Motion picture and sound recording industries



MotorVehiclePartsDealers

Motor vehicle and parts dealers



MotorVehiclePartsAccessories

Motor vehicle parts and accessories



MotorVehiclesParts

Motor vehicles and parts



MotorVehiclesBodiesTrailersParts

Motor vehicles, bodies and trailers, and parts



MotorVehiclesBodiesTrailersPartsManufacturing

Motor vehicles, bodies and trailers, and parts manufacturing



MultimerchandiseShopping

Multimerchandise shopping



Music

Music



MusicalInstruments

Musical instruments



NationalDefense

National defense



NaturalGasDistribution

Natural gas distribution



Noncorporate

Noncorporate



Nondefense

Nondefense



NondepositoryCreditIntermediation

Nondepository credit intermediation



NondurableGoods

Nondurable goods



NonfarmNonmanufacturing

Nonfarm nonmanufacturing



NonfarmNonmanufacturingNonresidentialFixedAssetsOnly

Nonfarm nonmanufacturing (nonresidential fixed assets only)



Nonfinancial

Nonfinancial



Nonmanufacturing

Nonmanufacturing



NonmedicalInstruments

Nonmedical instruments



NonmetallicMineralProducts

Nonmetallic mineral products



NonprofitInstitutions

Nonprofit institutions



NonprofitInstitutionsServingHouseholdsNpishs

Nonprofit institutions serving households (NPISHs)



Nonresidential

Nonresidential



NonresidentialEquipment

Nonresidential equipment



NonresidentialIntellectualPropertyProducts

Nonresidential intellectual property products



NonresidentialStructures

Nonresidential structures



NursingResidentialCareFacilities

Nursing and residential care facilities



Office

Office



OfficeAccountingEquipment

Office and accounting equipment



OilGasExtraction

Oil and gas extraction



Other

Other



OtherCommercial

Other commercial



OtherComputerElectronicProductManufacturing

Other computer and electronic product manufacturing



OtherDurableGoods

Other durable goods



OtherEquipment

Other equipment



OtherIntermediation

Other intermediation



OtherManufacturing

Other manufacturing



OtherNonprofitInstitutions

Other nonprofit institutions



OtherNonresidentialEquipment

Other nonresidential equipment



OtherPower

Other power



OtherResidential

Other residential



OtherRetail

Other retail



OtherServicesExceptGovernment

Other services, except government



OtherStructures

Other structures



OtherTransportationSupportActivities

Other transportation and support activities



OtherTransportationEquipment

Other transportation equipment



OtherTrucksBusesTruckTrailers

Other trucks, buses, and truck trailers



OwnAccount

Own account



OwnerOccupied

Owner-occupied



PaperProducts

Paper products



Partnerships

Partnerships



PerformingArtsSpectatorSportsMuseumsRelatedActivities

Performing arts, spectator sports, museums, and related activities



PermanentSite

Permanent site



PetroleumCoalProducts

Petroleum and coal products



PetroleumNaturalGas

Petroleum and natural gas



PharmaceuticalMedicineManufacturing

Pharmaceutical and medicine manufacturing



PhotocopyRelatedEquipment

Photocopy and related equipment



PipelineTransportation

Pipeline transportation



PlasticsRubberProducts

Plastics and rubber products



Power

Power



PowerCommunication

Power and communication



Prepackaged

Prepackaged



PrimaryMetals

Primary metals



PrintingRelatedSupportActivities

Printing and related support activities



Private

Private



PrivateGovernmentFixedAssets

Private and government fixed assets



PrivateFixedAssets

Private fixed assets



PrivateNonresidentialFixedAssets

Private nonresidential fixed assets



ProfessionalScientificTechnicalServices

Professional, scientific, and technical services



PublicSafety

Public safety



PublishingIndustriesIncludesSoftware

Publishing industries (includes software)



RailroadEquipment

Railroad equipment



RailroadTransportation

Railroad transportation



RealEstate

Real estate



RealEstateRentalLeasing

Real estate and rental and leasing



RecreationalBooks

Recreational books



RecreationalGoodsVehicles

Recreational goods and vehicles



Religious

Religious



RentalLeasingServicesLessorsOfIntangibleAssets

Rental and leasing services and lessors of intangible assets



ResearchDevelopment

Research and development



Residential

Residential



ResidentialEquipment

Residential equipment



ResidentialFixedAssets

Residential fixed assets



ResidentialStructures

Residential structures



RetailTrade

Retail trade



ScientificResearchDevelopmentServices

Scientific research and development services



SecuritiesCommodityContractsInvestments

Securities, commodity contracts, and investments



SemiconductorOtherElectronicComponentManufacturing

Semiconductor and other electronic component manufacturing



ServiceIndustryMachinery

Service industry machinery



SewerSystems

Sewer systems



Ships

Ships



ShipsBoats

Ships and boats



SocialAssistance

Social assistance



Software

Software



SoleProprietorships

Sole proprietorships



SoleProprietorshipsPartnerships

Sole proprietorships and partnerships



SpecialCare

Special care



SpecialIndustryMachineryNec

Special industry machinery, n.e.c.



SportingEquipmentSuppliesGunsAmmunition

Sporting equipment, supplies, guns, and ammunition



SportsRecreationalVehicles

Sports and recreational vehicles



StateLocal

State and local



Structures

Structures



SupportActivitiesForMining

Support activities for mining



TaxExemptCooperatives

Tax-exempt cooperatives



TelephoneFacsimileEquipment

Telephone and facsimile equipment



TenantOccupied

Tenant-occupied



TextileMillsTextileProductMills

Textile mills and textile product mills



TheatricalMovies

Theatrical movies



TherapeuticAppliancesEquipment

Therapeutic appliances and equipment



ToolsEquipmentForHouseGarden

Tools and equipment for house and garden



TransitGroundPassengerTransportation

Transit and ground passenger transportation



Transportation

Transportation



TransportationWarehousing

Transportation and warehousing



TransportationEquipment

Transportation equipment



Transportion

Transportion



TruckTransportation

Truck transportation



TrucksBusesTruckTrailers

Trucks, buses, and truck trailers



UniversitiesColleges

Universities and colleges



Utilities

Utilities



Vehicles

Vehicles



VideoAudioPhotographicInformationProcessingEquipmentMedia

Video, audio, photographic, and information processing equipment and media



Warehouses

Warehouses



WarehousingStorage

Warehousing and storage



WasteManagementRemediationServices

Waste management and remediation services



WaterSystems

Water systems



WaterTransportation

Water transportation



WaterSewageOtherSystems

Water, sewage, and other systems



WholesaleTrade

Wholesale trade



WoodProducts

Wood products

Implementations

Source

impl FixedAssetLine

pub fn description(&self) -> &'static str

Returns the original string description for this fixed asset line

pub fn from_description(description: &str) -> Option<Self>

Creates a FixedAssetLine from a description string

pub fn codes(&self) -> Vec<i64>

Returns the code values associated with this fixed asset line