Returns an iterator over the Mne struct for the AMNE dataset.
Used to create API calls with SeriesID, State and Years set to “ALL”.
Includes footnotes.
The Currency type represents BEA values by embedding the raw data value with contextual
metadata related to unit multipliers and currency standard.
Prevents misinterpretation of raw data values and facilitates conversion between value types.
The DatasetDetails type represents dataset descriptions in a BEA response. This data type is
an intermediary between the serde_json::Value representation and the strongly-typed
internal representation, implemented using the lowly String.
GdpData represents the Data portion of the Results from a BEA response.
These portions of the response have corresponding internal library representations, Data,
Results and BeaResponse respectively. This is the data type contained
within the [Data::GdpData] variant.
This iterator returns all values for indicator, frequency, and years regardless of whether the
user subsets the Ita struct that generates the iterator.
Returns an iterator over the Mne struct for Direct Investment data.
Used to create API calls with SeriesID, State and Years set to “ALL”.
Includes footnotes.
The NipaYear struct contains fields associated with the BEA response for Year parameter
values in the NIPA dataset. The fields define ranges of years for which table data is
available for a given frequency (annual, monthly or quartelry), using the pattern
first_{frequency}_year and last_{frequency}_year.
The MNE dataset includes row numbers for summary statistics over industries that do not
correspond to valid NAICS codes. The NaicsSupplement type accommodates these additional
categories.
Represents the various table types available in the National Income and Product Accounts (NIPA).
Each variant corresponds to a specific NIPA table with a unique identifier.